@@ -240,7 +240,7 @@ static int xsh_respon_slit_nod_create(cpl_plugin *plugin){
 
   /* Set generic parameters (common to all recipes) */
   check( xsh_parameters_generic( RECIPE_ID, recipe->parameters ) ) ;
-  xsh_parameters_decode_bp(RECIPE_ID,recipe->parameters,-1);
+  xsh_parameters_decode_bp(RECIPE_ID,recipe->parameters,DECODE_BP_FLAG_NOD);
   check( xsh_parameters_pre_overscan( RECIPE_ID, recipe->parameters ) ) ;
   check(xsh_parameters_stack_create(RECIPE_ID,recipe->parameters,stack_param));
 
@@ -293,6 +293,17 @@ static int xsh_respon_slit_nod_create(cpl_plugin *plugin){
 				       "correct-sky-by-median", TRUE,
     "TRUE if the resampled spectrum at each wavelength is median subtracted to remove sky lines"));
 
+/*
+    check( xsh_parameters_new_int( recipe->parameters, RECIPE_ID,
+       "scale-stack-method",4,
+       "frame stacking scaling method (<=3): 0 (on-scaling); 1 (scaling-uniform on slit); 2 (scaling-slice on slit); 3 (pix-pix scaling)"));
+*/
+
+    check( xsh_parameters_new_int( recipe->parameters, RECIPE_ID,
+       "scale-combine-nod-method",1,
+       "frame scaling when nod frames are combined: 0 (no-scaling); 1 (scaling)"));
+
+
  cleanup:
   if ( cpl_error_get_code() != CPL_ERROR_NONE ){
     xsh_error_dump(CPL_MSG_ERROR);
@@ -471,7 +482,8 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   xsh_interpolate_bp_param *ipol_bp=NULL;
   int corr_tell=0;
   int corr_sky=0;
-
+  int scale_nod=0;
+  cpl_frame* frm_rejected=NULL;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -488,7 +500,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   assure( instrument->mode == XSH_MODE_SLIT, CPL_ERROR_ILLEGAL_INPUT,
           "Instrument NOT in Slit Mode");
 
-  check(xsh_ensure_raws_number_is_even(raws));
+  check(frm_rejected=xsh_ensure_raws_number_is_even(raws));
   xsh_recipe_params_check(parameters,instrument,RECIPE_ID);
   //check(airm=xsh_utils_compute_airm_eff(raws));
  
@@ -551,7 +563,12 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
                                                       "correct-tellurics"));
   check( corr_sky = xsh_parameters_get_boolean( parameters, RECIPE_ID,
                                                       "correct-sky-by-median"));
-
+  check( scale_nod = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                                 "scale-combine-nod-method"));
+  /*
+  check( scale_stack = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                                   "scale-stack-method"));
+  */
   check(xsh_frameset_uniform_bin(&raws_ord_set, &calib,instrument));
   check( xsh_respon_slit_nod_get_calibs(calib,instrument,
                                        &bpmap,&master_bias,&master_flat,
@@ -682,7 +699,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   sprintf( comb_tag,"%s_%s",
     rec_prefix, XSH_GET_TAG_FROM_ARM( XSH_ORDER2D, instrument));
   check( comb_frame = xsh_combine_nod( comb_set, combine_nod_par,
-    comb_tag, instrument,&combeso_frame));
+    comb_tag, instrument,&combeso_frame,scale_nod));
 
 
   /* 2D product */
@@ -762,7 +779,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
      disp_tab_frame != NULL && comb_eff_set != NULL) {
      check( comb_eff_frame = xsh_combine_nod( comb_eff_set, combine_nod_par,
                                               comb_tag, instrument,
-                                              &combeffeso_frame));
+                                              &combeffeso_frame,scale_nod));
 
      xsh_msg( "Extract 1D order-by-order spectrum" ) ;
      check( res1D_eff_frame = xsh_extract_clean( comb_eff_frame, loc_table_frame,
@@ -801,7 +818,9 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   }
 
   /* Save products */
-
+  if(frm_rejected != NULL ) {
+       //cpl_frameset_erase_frame(frameset,frm_rejected);
+  }
   if(response_ord_frame!=NULL) {
     check( xsh_add_product_table(response_ord_frame, frameset, parameters,
                                        RECIPE_ID, instrument,NULL));
@@ -882,7 +901,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
     xsh_free_frameset( &comb_set);
     xsh_free_frameset( &comb_eff_set);
     xsh_free_frame( &comb_eff_frame);
-
+    xsh_free_frame( &bpmap);
     xsh_free_frame( &response_ord_frame);
     xsh_free_frame( &response_frame);
     xsh_free_frame( &combeso_frame);
