@@ -120,9 +120,11 @@ Tag = OBJECT_SLIT_STARE_UVB)\n\
   - [OPTIONAL,physmod mode] A table listing sky line positions (Tag = SKY_LINE_LIST_arm)\n\
     this is used to be able to control quality of sky subtraction, for example\n\
     projecting guess positions on the product SCI_SLIT_STARE_SUB_SKY_arm\n\
-  - [OPTIONAL] The instrument response table (Tag = RESPONSE_ORDER1D_SLIT_arm)\n\
+  - [OPTIONAL] The instrument response table (Tag = RESPONSE_MERGE1D_SLIT_arm)\n\
   - [OPTIONAL] An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
   - [OPTIONAL] A telluric mask (Tag = TELL_MASK_arm)\n\
+  - [OPTIONAL] The instrument master response table (Tag = MRESPONSE_MERGE1D_SLIT_arm).\n\
+    If both master and individual response are provided the individual response is preferred.\n\
 Products : \n\
   - PREFIX_ORDER2D_arm extracted spectrum, order-by-order, 2D\n\
   - PREFIX_ORDER1D_arm extracted spectrum, order-by-order, 1D\n\
