@@ -236,6 +236,36 @@ cpl_mask * xsh_bpm_filter(
     return filtered_mask;
 }
 
+/**
+ * Create the bad pixel map (cpl format) attached to the XSH format
+ * Bad Pixel Map image
+ *
+ * @param image the image on which attaches the cpl bpmap
+ * @param bpmap XSH format bad pixel map
+ * @param decode_bp bad pixel code to be rejected
+ */
+cpl_mask*
+xsh_code_is_in_qual(cpl_image * qual, const int code) {
+  cpl_mask *mask = NULL;
+
+  assure( qual != NULL, CPL_ERROR_NULL_INPUT,
+      "QUAL input is NULL pointer" );
+  cpl_size nx=cpl_image_get_size_x(qual);
+  cpl_size ny=cpl_image_get_size_y(qual);
+
+  mask=cpl_mask_new(nx,ny);
+  int* pqual=cpl_image_get_data_int(qual);
+  cpl_binary* pmask=cpl_mask_get_data(mask);
+  int size=nx*ny;
+  for(int i=0;i<size;i++){
+      if( (pqual[i] & code) ==0 ) {
+          /* if pixel is bad flag it in table */
+          pmask[i]=CPL_BINARY_1;
+      }
+  }
+  cleanup:
+  return mask;
+}
 
 /**
  * Create the bad pixel map (cpl format) attached to the XSH format
@@ -661,12 +691,18 @@ void xsh_bpmap_collapse_mean(cpl_image * mean, cpl_imagelist * list,
 cpl_error_code
 xsh_badpixel_flag_rejected(cpl_image* qual, cpl_image* image)
 {
-
+	assure( CPL_TYPE_INT == cpl_image_get_type(qual), cpl_error_get_code(),
+	    		"wrong ima qual data type");
     int nx = cpl_image_get_size_x(qual);
     int ny = cpl_image_get_size_y(qual);
+    //xsh_msg("nx=%d ny=%d",nx,ny);
+    //nx = cpl_image_get_size_x(image);
+    //ny = cpl_image_get_size_y(image);
+    //xsh_msg("nx=%d ny=%d",nx,ny);
+
     int* pqual=cpl_image_get_data_int(qual);
     cpl_mask* bpm=cpl_image_get_bpm(image);
-    int* pbpm=cpl_mask_get_data(bpm);
+    cpl_binary* pbpm=cpl_mask_get_data(bpm);
     //xsh_msg("Bitwise OR combine");
     for(int j=0;j<ny;j++) {
         int j_nx=j*nx;
@@ -677,6 +713,7 @@ xsh_badpixel_flag_rejected(cpl_image* qual, cpl_image* image)
             }
         }
     }
+    cleanup:
     return cpl_error_get_code();
 }
 
@@ -1401,9 +1438,10 @@ xsh_count_satpix(xsh_pre* pre, xsh_instrument* instr,const int datancom)
 
 cpl_error_code
 xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
-                                      const double cor_val, int flag, int* nsat)
+                                      const double cor_val, const int flag,
+									  const int is_flat, int* nsat)
 {
-    int size=0;
+    //int size=0;
     int i=0;
     float* pima=NULL;
     int* pqual=NULL;
@@ -1415,14 +1453,18 @@ xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
 
     XSH_ASSURE_NOT_NULL_MSG(pre, "Null input pre frame");
     XSH_ASSURE_NOT_NULL_MSG(instr, "Null input pre frame");
-    size=pre->nx*pre->ny;
+    //size=pre->nx*pre->ny;
     /* define thresholds and corresponding codes */
     bp_code_sat=QFLAG_ADC_SATURATION;
     bp_code_neg=QFLAG_NEGATIVE_DATA;
     if(xsh_instrument_get_arm(instr) != XSH_ARM_NIR) {
         thresh_max=65000;
     } else {
-        thresh_max=42000;
+    	if (is_flat) {
+    		 thresh_max=100000;
+    	} else {
+    		 thresh_max=42000;
+    	}
         bp_code_sat=QFLAG_SATURATED_DATA;
     }
 
@@ -1439,11 +1481,12 @@ xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
     thresh_max=thresh_max -cor_val;
     /* position of bottom left edge of NIR frame corresponding to K band */
     int knx=758;
+    knx=1000;
     if(flag) {
         double thresh_min=1-cor_val;
         for(j=0;j<ny;j++) {
             jnx=j*nx;
-            for(i=0;i<knx;i++) {
+            for(i=0;i<nx;i++) {
                 ipix=i+jnx;
                 //for(ipix=0;ipix<size;ipix++) {
                 cpima=pima[ipix];
