@@ -528,6 +528,7 @@ xsh_pre* xsh_pre_create(cpl_frame* raw, cpl_frame* bpmap, cpl_image* bias_data,
   result->ny = result->naxis2 - result->cutmy - result->cuty;
 
   /* in NIR mode */
+  int is_flat = xsh_pfits_is_flat(result->data_header);
   if (xsh_instrument_get_arm(instr) == XSH_ARM_NIR) {
 
     XSH_ASSURE_NOT_ILLEGAL(result->nx > 0 && result->ny > 0);
@@ -581,8 +582,9 @@ xsh_pre* xsh_pre_create(cpl_frame* raw, cpl_frame* bpmap, cpl_image* bias_data,
     /* to flag bad pixel we need the qual extension initialized */
        result->qual=cpl_image_new(result->nx,result->ny,XSH_PRE_QUAL_TYPE);
     /* Flag negative saturated and (NIR) extrapolated pixels */
+
     xsh_badpixelmap_flag_saturated_pixels(result, instr, cor_val,
-        flag_neg_and_thresh_pix, &nsat);
+        flag_neg_and_thresh_pix, is_flat, &nsat);
     frac_sat = (double) nsat / (nx_ny);
 
     xsh_pfits_set_wcs(result->data_header,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
@@ -656,7 +658,7 @@ xsh_pre* xsh_pre_create(cpl_frame* raw, cpl_frame* bpmap, cpl_image* bias_data,
 
     /* flag saturated pixels for QC */
      check(xsh_badpixelmap_flag_saturated_pixels(result, instr, cor_val,
-        flag_neg_and_thresh_pix, &nsat));
+        flag_neg_and_thresh_pix, is_flat, &nsat));
     int nx_ny = result->nx * result->ny;
     frac_sat = (double) nsat / (nx_ny);
 
@@ -1407,9 +1409,9 @@ void xsh_pre_add (xsh_pre* self, const xsh_pre * right)
   float* errs1 = NULL;
   float* errs2 = NULL;
   int i = 0;
-  cpl_mask* mask = NULL;
-  cpl_binary* binary =NULL;
-  int* qual = NULL;
+  //cpl_mask* mask = NULL;
+  //cpl_binary* binary =NULL;
+  //int* qual = NULL;
 
   XSH_ASSURE_NOT_NULL(self);
   XSH_ASSURE_NOT_NULL(right);
@@ -1433,11 +1435,11 @@ void xsh_pre_add (xsh_pre* self, const xsh_pre * right)
     errs1[i] = sqrt(pow(errs1[i],2)+pow(errs2[i],2));
   }
     
-  /* QUAL computation */
+  /* QUAL computation: combine the two QUAL codes */
 
-  /* IF there is a CALIB */
+  /* IF there is a CALIB
   if( (xsh_pre_get_group(right) == CPL_FRAME_GROUP_CALIB) ){ 
-    /* PUT QFLAG CALIB DEFECT */
+    // PUT QFLAG CALIB DEFECT
     check( mask = xsh_pre_get_bpmap(right));
     check(binary = cpl_mask_get_data(mask));
     check(qual = cpl_image_get_data_int(self->qual));
@@ -1447,14 +1449,12 @@ void xsh_pre_add (xsh_pre* self, const xsh_pre * right)
       }
     } 
   }
-  /* Add the two QUAL code */
   else {
-    /*
-      check (cpl_image_add(self->qual, right->qual));  
-      Need a function to "OR" 2 images
-    */
+    // Need a function to "OR" 2 images
     xsh_badpixelmap_or( self, right ) ;
   }
+  */
+  xsh_badpixelmap_or( self, right ) ;
 cleanup:
   return;
 }
@@ -1588,9 +1588,9 @@ void xsh_pre_subtract (xsh_pre* self, const xsh_pre * right)
   float* errs1 = NULL;
   float* errs2 = NULL;
   int i = 0;
-  cpl_mask* mask = NULL;
-  cpl_binary* binary =NULL;
-  int* qual = NULL;
+  //cpl_mask* mask = NULL;
+  //cpl_binary* binary =NULL;
+  //int* qual = NULL;
 
   /* Check input */
   XSH_ASSURE_NOT_NULL( self);
@@ -1615,23 +1615,24 @@ void xsh_pre_subtract (xsh_pre* self, const xsh_pre * right)
     errs1[i] = sqrt(pow(errs1[i],2)+pow(errs2[i],2));
   }
 
-  /* Handle qual unit + plist */
+  /* Handle qual unit + plist
   if( (xsh_pre_get_group(right) == CPL_FRAME_GROUP_CALIB) ){
     check( mask = xsh_pre_get_bpmap(right));
     check(binary = cpl_mask_get_data(mask));
     check(qual = cpl_image_get_data_int(self->qual));
     for(i=0;i<self->nx*self->ny;i++){
       if ( (binary[i] & self->decode_bp) > 0 ){
-        /* this is a bad pixel */
+        // this is a bad pixel
         qual[i] |= QFLAG_CALIB_FILE_DEFECT;
       }
     }
   }
   else {
-    /* In case the inputs are RAW frames */
+    // In case the inputs are RAW frames
     xsh_badpixelmap_or( self, right ) ;
   }
-
+  */
+  xsh_badpixelmap_or( self, right ) ;
   cleanup:
     return ;
 }
@@ -1812,13 +1813,16 @@ void xsh_pre_divide (xsh_pre* self, const xsh_pre * right, double threshold)
   for(i=0;i< nx_ny; i++){
 
     if ( (qual2[i] & self->decode_bp) > 0 ) {
-      /* bad pixel */
+      // pixel quality
+      /*
       if( (xsh_pre_get_group(right) == CPL_FRAME_GROUP_CALIB) ){
         qual1[i] |= QFLAG_CALIB_FILE_DEFECT;
       }
       else {
         qual1[i] |= qual2[i];
       }
+      */
+      qual1[i] |= qual2[i];
     }
     else if ( fabs(data2[i]) < threshold){
       qual1[i] |= QFLAG_DIVISOR_ZERO;
@@ -1898,13 +1902,16 @@ void xsh_pre_multiply (xsh_pre* self, const xsh_pre * right, double threshold)
   for(i=0;i< nx_ny; i++){
 
     if ( (qual2[i] & self->decode_bp) > 0 ) {
-      /* bad pix */
+      // pixel quality
+      /*
       if( (xsh_pre_get_group(right) == CPL_FRAME_GROUP_CALIB) ){
         qual1[i] |= QFLAG_CALIB_FILE_DEFECT;
       }
       else {
         qual1[i] |= qual2[i];
       }
+      */
+      qual1[i] |= qual2[i];
     }
     else if ( fabs(data2[i]) > threshold){
       qual1[i] |= QFLAG_OUTSIDE_DATA_RANGE;
