@@ -373,9 +373,9 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
   int ilambda_max=0;
   int mstart=0;
   int mend=0;
-  int code_extrap=1048576;
+  //int code_extrap=1048576;
   //int code_special=2143289343;
-  int code_special=2147483647;
+  //int code_special=2147483647;
   int decode_bp = instrument->decode_bp;
   //decode_bp = code_special;
   /* check if there are bad pixels to be interpolated, else we can integrate */
@@ -612,9 +612,9 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
     double *res_lambda = NULL;
     float *res_flux = NULL, *res_errs = NULL;
     int *res_qual = NULL;
-    float* pima;
-    float* fima;
-    float* rima;
+    float* pima=NULL;
+    float* fima=NULL;
+    float* rima=NULL;
 #if debug_extraction
     cpl_image* prof_ima =cpl_image_new(nlambda,nslit,CPL_TYPE_FLOAT);
     cpl_image* flux_ima =cpl_image_new(nlambda,nslit,CPL_TYPE_FLOAT);
