@@ -159,7 +159,28 @@ static void get_errors( float *err, int ix, int iy, int nx, int ny,
 
 */
 /*****************************************************************************/
+static float
+xsh_fill_gauss(const int j, const float A, const float sigma, const float bkg,
+               const float y_c)
+{
 
+    /* add Gauss profile positioned where the trace is
+     * I=A*exp( -0.5*( (X-Xo)/sigma )^2 ) +bkg
+     */
+    float gauss;
+    float arg = 0;
+    float y;
+
+    /* uniform along X (horizontal direction) Gauss along Y (vertical)  */
+
+    y=j;
+
+    arg = (y - y_c) / sigma;
+    arg *= arg;
+    gauss = (A * expf(-0.5 * arg) + bkg);
+    //xsh_msg("y=%g y_c=%g arg=%g gauss=%g",y,y_c,arg,gauss);
+    return gauss;
+}
 /*****************************************************************************/
 static void 
 xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec, 
@@ -789,6 +810,7 @@ adjust_lambdas( xsh_spectralformat_list * spec_list,
   }
 }
 
+/* AMO: function not used
 static float 
 get_step_slit( float * slit, int nslit )
 {
@@ -803,7 +825,7 @@ get_step_slit( float * slit, int nslit )
   return result ;
   
 }
-
+*/
 
 /*****************************************************************************/
 /** 
@@ -1168,7 +1190,7 @@ xsh_rectify_orders( cpl_frame *sci_frame,
     rec_max_index = rec_list->size-1;
   }
 
-  /* AMO added to make sure bad pixels are flagged before re-sampling */
+  /* AMO added to make sure bad pixels are flagged before re-sampling 
 
     //xsh_msg("ok1");
     //int decode_bp=2147483647;
@@ -1177,7 +1199,7 @@ xsh_rectify_orders( cpl_frame *sci_frame,
     cpl_image_reject_from_mask(pre_sci->data,mask);
     //cpl_detector_interpolate_rejected(pre_sci->data);
     xsh_free_mask(&mask);
-
+  */
 
 
   for( i = rec_min_index; i <= rec_max_index; i++ ) {
@@ -1350,13 +1372,13 @@ void xsh_compute_slitlet_limits( cpl_frameset *shift_set, double sdown,
   double sldown, double slup, double sup, double slit_bin,
   double *slitmin_tab, int *nslit_tab, double *slitcen_tab)
 {
-  double offset_down, offset_cen, offset_up;
+  double offset_down=0, offset_cen=0, offset_up=0;
   double cen_slitlet_down_size;
-  double cen_slitlet_up_size;
+  double cen_slitlet_up_size=0;
   double down_slitlet_down_size;
   double down_slitlet_up_size;
   double up_slitlet_down_size;
-  double up_slitlet_up_size;
+  double up_slitlet_up_size=0;
   double slitlet_up_size;
   double slitlet_down_size;
   double cen_ref_down, cen_ref_up;
