@@ -381,6 +381,8 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
   check( errsList = cpl_imagelist_new());
 
   /* Populate image lists with images in frame set */
+  cpl_mask* mask_comb;;
+  cpl_mask* mask_tmp;
   for (i=0;i < size;i++){
 
     check(current = cpl_frameset_get_frame(rawFrames,i));
@@ -390,6 +392,7 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
     /* inject bad pixels to change statistics */
     xsh_image_flag_bp(pre->data, pre->qual, instr);
     xsh_image_flag_bp(pre->errs, pre->qual, instr);
+    mask_tmp=cpl_image_get_bpm(pre->data);
 
     check_msg( cpl_imagelist_set(dataList,cpl_image_duplicate(pre->data), 
       i),"Can't add Data Image %d to imagelist", i) ;
@@ -402,9 +405,11 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
 
     /* combining bad pixels */
     if (i == 0) {
+      mask_comb=cpl_mask_duplicate(mask_tmp);
       qual_comb = cpl_image_duplicate(pre->qual);
     } else {
       xsh_badpixelmap_image_coadd(&qual_comb, pre->qual, mode_and);
+      cpl_mask_or(mask_comb,mask_tmp);
     }
 
     /* Free memory */
@@ -412,14 +417,12 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
       xsh_pre_free(&pre);
     }
   }
- 
+  //xsh_bpmap_mask_bad_pixel(qual_comb,mask_comb,QFLAG_INCOMPLETE_DATA);
   /*free memory on product extensions that will be re-allocated later on (errs is only modified) */
     xsh_free_image(&pre->data);
     xsh_free_image(&pre->qual);
+    cpl_mask_delete(mask_comb);
 
-    /* store combined bp map in qual extension of result */
-    pre->qual = cpl_image_duplicate(qual_comb);
-    xsh_free_image(&qual_comb);
 
   
   /* computes the median or sigma-clipped mean on data and errs */
@@ -434,7 +437,14 @@ xsh_remove_cosmics (cpl_frameset * rawFrames,
      check( xsh_collapse_errs(pre->errs,errsList,1));
 
    }
+   int nrej=cpl_image_count_rejected(pre->data);
+   if(nrej>0) {
+     xsh_badpixel_flag_rejected(pre->data,qual_comb);
+   }
 
+   /* store combined bp map in qual extension of result */
+   pre->qual = cpl_image_duplicate(qual_comb);
+   xsh_free_image(&qual_comb);
 
     /* loop to remove cosmics */
     if ( size >= 3 && crh_clipping != NULL) {
